Module: AutoTest::Authentication
- Included in:
- AutoTest
- Defined in:
- lib/authentication.rb
Class Method Summary collapse
-
.get_login_attributes ⇒ Object
return the login attributes.
- .get_login_data ⇒ Object
- .get_login_fields ⇒ Object
- .get_login_names ⇒ Object
-
.get_login_path ⇒ Object
get the login path.
- .get_logout_path ⇒ Object
- .get_unique_login_attribute_name ⇒ Object
- .get_user_data ⇒ Object
-
.get_users ⇒ Object
return the users.
- .get_users_from_db(user_class_name, bool) ⇒ Object
- .init_login_data ⇒ Object
-
.init_users ⇒ Object
initialize the @users array.
-
.login(user, session) ⇒ Object
login a user.
- .logout(session) ⇒ Object
-
.set_login_attribute_names(names, fields) ⇒ Object
set the attribute_names and fields that are needed to login the argument are two arrays, the first are the database names of the attribute the second are the belonging field names.
- .set_login_data(*data) ⇒ Object
- .set_login_fields(fields) ⇒ Object
- .set_login_names(names) ⇒ Object
-
.set_login_path(path) ⇒ Object
set the login path.
- .set_logout_path(path) ⇒ Object
- .set_unique_login_attribute_name(name) ⇒ Object
- .set_user_data(value) ⇒ Object
- .use_db_users ⇒ Object
- .user_class ⇒ Object
Class Method Details
.get_login_attributes ⇒ Object
return the login attributes
30 31 32 |
# File 'lib/authentication.rb', line 30 def get_login_attributes @login_attributes end |
.get_login_data ⇒ Object
49 50 51 |
# File 'lib/authentication.rb', line 49 def get_login_data @data end |
.get_login_fields ⇒ Object
82 83 84 |
# File 'lib/authentication.rb', line 82 def get_login_fields @fields end |
.get_login_names ⇒ Object
73 74 75 |
# File 'lib/authentication.rb', line 73 def get_login_names @names end |
.get_login_path ⇒ Object
get the login path
35 36 37 |
# File 'lib/authentication.rb', line 35 def get_login_path @login end |
.get_logout_path ⇒ Object
18 19 20 |
# File 'lib/authentication.rb', line 18 def get_logout_path @logout end |
.get_unique_login_attribute_name ⇒ Object
90 91 92 |
# File 'lib/authentication.rb', line 90 def get_unique_login_attribute_name @unique_login end |
.get_user_data ⇒ Object
124 125 126 |
# File 'lib/authentication.rb', line 124 def get_user_data @user_data end |
.get_users ⇒ Object
return the users
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/authentication.rb', line 103 def get_users if @db_users[0] then @users = @db_users[1].find(:all) else index = get_login_names.index(get_unique_login_attribute_name) @users = [] @db_users[1].find(:all).each do |u| get_login_data.each do |d| if d[index] == u.send(get_unique_login_attribute_name.to_sym) then @users << u end end end end return @users end |
.get_users_from_db(user_class_name, bool) ⇒ Object
60 61 62 63 64 65 66 67 |
# File 'lib/authentication.rb', line 60 def get_users_from_db(user_class_name, bool) @users = user_class_name.find(:all) if bool then @db_users = [true, user_class_name] else @db_users = [false, user_class_name] end end |
.init_login_data ⇒ Object
45 46 47 |
# File 'lib/authentication.rb', line 45 def init_login_data @data = [] end |
.init_users ⇒ Object
initialize the @users array
8 9 10 11 |
# File 'lib/authentication.rb', line 8 def init_users @users = [] @db_users = [false, nil] end |
.login(user, session) ⇒ Object
login a user
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/authentication.rb', line 141 def login(user, session) begin session.visit get_login_path user = user.class.find(user.id) hash = Hash.new hash["#{Test.get_sessions_array.index(session)}:#{session.current_path}"] = Page.all_submits(session).first.value Test.add_to_action_path hash Page.check_for_error_code(session) index = get_login_names.index(get_unique_login_attribute_name) @db_users[1].find(:all).each do |u| get_login_data.each do |d| if d[index] == u.send(get_unique_login_attribute_name.to_sym) then set_user_data(get_login_data[index]) end end end if @db_users[0] then get_login_attributes.each do |field| session.fill_in field[1], :with => user.send(field[0].to_sym) end else get_login_attributes.each_with_index do |field, i| session.fill_in field[1], :with => get_user_data[i] end end session. Page.all_submits(session).first.value Page.check_for_error_code(session) rescue (ActiveRecord::RecordNotFound) Test.sessions(Test.get_sessions_array.index(session), "depth", Test.get_max_depth+1) Test.sessions(Test.get_sessions_array.index(session), "current_depth", Test.get_sessions(Test.get_sessions_array.index(session), "depth")) end end |
.logout(session) ⇒ Object
129 130 131 132 133 134 135 136 137 138 |
# File 'lib/authentication.rb', line 129 def logout(session) begin hash = Hash.new hash["#{Test.get_sessions_array.index(session)}:#{session.current_path}"] = get_logout_path Test.add_to_action_path hash session.visit get_logout_path Page.check_for_error_code(session) rescue => e end end |
.set_login_attribute_names(names, fields) ⇒ Object
set the attribute_names and fields that are needed to login the argument are two arrays, the first are the database names of the attribute the second are the belonging field names
25 26 27 |
# File 'lib/authentication.rb', line 25 def set_login_attribute_names(names, fields) @login_attributes = names.zip fields end |
.set_login_data(*data) ⇒ Object
53 54 55 56 57 58 |
# File 'lib/authentication.rb', line 53 def set_login_data(*data) data.each do |d| @data << d end end |
.set_login_fields(fields) ⇒ Object
78 79 80 |
# File 'lib/authentication.rb', line 78 def set_login_fields(fields) @fields = fields end |
.set_login_names(names) ⇒ Object
69 70 71 |
# File 'lib/authentication.rb', line 69 def set_login_names(names) @names = names end |
.set_login_path(path) ⇒ Object
set the login path
40 41 42 |
# File 'lib/authentication.rb', line 40 def set_login_path(path) @login = path end |
.set_logout_path(path) ⇒ Object
14 15 16 |
# File 'lib/authentication.rb', line 14 def set_logout_path(path) @logout = path end |
.set_unique_login_attribute_name(name) ⇒ Object
86 87 88 |
# File 'lib/authentication.rb', line 86 def set_unique_login_attribute_name(name) @unique_login = name end |
.set_user_data(value) ⇒ Object
120 121 122 |
# File 'lib/authentication.rb', line 120 def set_user_data(value) @user_data = value end |
.use_db_users ⇒ Object
94 95 96 |
# File 'lib/authentication.rb', line 94 def use_db_users @db_users[0] end |
.user_class ⇒ Object
98 99 100 |
# File 'lib/authentication.rb', line 98 def user_class @db_users[1] end |